@@ -46,6 +46,7 @@ func (root *Root) draw(ctx context.Context) {
 	}
 
 	root.drawStatus()
+	root.drawTitle()
 	root.Screen.Show()
 }
 
@@ -223,6 +224,9 @@ func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 			break
 		}
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
+		if c.width == 2 {
+			n++
+		}
 	}
 	return lX, lN
 }
@@ -245,6 +249,9 @@ func (root *Root) drawNoWrapLine(y int, lX int, lN int, lineC LineC) (int, int)
 		}
 		c := lineC.lc[lX+n]
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
+		if c.width == 2 {
+			n++
+		}
 	}
 	lN++
 	return lX, lN
@@ -267,22 +274,28 @@ func (root *Root) drawVerticalHeader(y int, wrapNum int, lineC LineC) {
 	}
 
 	screen := root.Screen
-	for n := range widthVH {
+	x := root.scr.startX
+	for n := 0; n < widthVH; n++ {
 		c := DefaultContent
 		if n < len(lineC.lc) {
 			c = lineC.lc[n]
 		}
-		style := applyStyle(c.style, root.Doc.Style.VerticalHeader)
 		if n == widthVH-2 && c.width == 2 {
-			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
-			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			style := applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
+			screen.SetContent(x, y, c.mainc, c.combc, style)
 			return
 		} else if n == widthVH-1 {
-			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
-			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			style := applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
+			screen.SetContent(x, y, c.mainc, c.combc, style)
 			return
 		}
-		screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+		style := applyStyle(c.style, root.Doc.Style.VerticalHeader)
+		screen.SetContent(x, y, c.mainc, c.combc, style)
+		x++
+		if c.width == 2 {
+			x++
+			n++
+		}
 	}
 }
 
@@ -351,11 +364,30 @@ func (root *Root) drawLineNumber(lN int, y int, valid bool) {
 	root.Screen.SetContent(len(numC), y, ' ', nil, defaultStyle)
 }
 
+// drawTitle sets the terminal title if TerminalTitle is enabled.
+func (root *Root) drawTitle() {
+	if root.Config.SetTerminalTitle {
+		root.Screen.SetTitle(root.displayTitle())
+	}
+}
+
+// displayTitle returns the caption string of the document.
+func (root *Root) displayTitle() string {
+	if root.Doc.Caption != "" {
+		return root.Doc.Caption
+	}
+	return root.Doc.FileName
+}
+
 // setContentString is a helper function that draws a string with setContent.
 func (root *Root) setContentString(vx int, vy int, lc contents) {
 	screen := root.Screen
-	for x, content := range lc {
-		screen.SetContent(vx+x, vy, content.mainc, content.combc, content.style)
+	for n := 0; n < len(lc); n++ {
+		c := lc[n]
+		screen.SetContent(vx+n, vy, c.mainc, c.combc, c.style)
+		if c.width == 2 {
+			n++
+		}
 	}
 	screen.SetContent(vx+len(lc), vy, 0, nil, defaultStyle.Normal())
 }
