@@ -2,6 +2,8 @@ package oviewer
 
 import (
 	"context"
+	"log"
+	"slices"
 	"sync/atomic"
 )
 
@@ -37,7 +39,10 @@ func (root *Root) hasDocChanged() bool {
 
 // addDocument adds a document and displays it.
 func (root *Root) addDocument(ctx context.Context, addDoc *Document) {
-	root.mu.Lock()
+	if !root.mu.TryLock() {
+		log.Print("failed to acquire lock")
+		return
+	}
 	root.DocList = append(root.DocList, addDoc)
 	root.mu.Unlock()
 
@@ -47,12 +52,17 @@ func (root *Root) addDocument(ctx context.Context, addDoc *Document) {
 
 // insertDocument inserts a document after the specified number and displays it.
 func (root *Root) insertDocument(ctx context.Context, num int, m *Document) {
-	root.mu.Lock()
+	if !root.mu.TryLock() {
+		log.Print("failed to acquire lock")
+		return
+	}
 	num = max(0, num)
 	num = min(len(root.DocList)-1, num)
 	root.DocList = append(root.DocList[:num+1], append([]*Document{m}, root.DocList[num+1:]...)...)
 	root.mu.Unlock()
 
+	go root.waitForEOF(m)
+
 	root.setDocumentNum(ctx, num+1)
 	root.setMessageLogf("insert %s%s", m.FileName, m.Caption)
 }
@@ -65,23 +75,28 @@ func (root *Root) closeDocument(ctx context.Context) {
 		return
 	}
 
-	root.setMessageLogf("close [%d]%s%s", root.CurrentDoc, root.Doc.FileName, root.Doc.Caption)
-
-	root.mu.Lock()
+	if !root.mu.TryLock() {
+		log.Print("failed to acquire lock")
+		return
+	}
 	num := root.CurrentDoc
 	root.DocList[num].requestClose()
-	root.DocList = append(root.DocList[:num], root.DocList[num+1:]...)
+	root.DocList = slices.Delete(root.DocList, num, num+1)
 	if num > 0 {
 		num--
 	}
 	root.mu.Unlock()
 
 	root.setDocumentNum(ctx, num)
+	root.setMessageLogf("close [%d]%s%s", root.CurrentDoc, root.Doc.FileName, root.Doc.Caption)
 }
 
 // closeAllDocumentsOfType closes all documents of the specified type.
 func (root *Root) closeAllDocumentsOfType(dType documentType) (int, []string) {
-	root.mu.Lock()
+	if !root.mu.TryLock() {
+		log.Print("failed to acquire lock")
+		return 0, nil
+	}
 	defer root.mu.Unlock()
 
 	docLen := len(root.DocList)
@@ -94,7 +109,7 @@ func (root *Root) closeAllDocumentsOfType(dType documentType) (int, []string) {
 		doc := root.DocList[i]
 		if doc.documentType == dType {
 			doc.requestClose()
-			root.DocList = append(root.DocList[:i], root.DocList[i+1:]...)
+			root.DocList = slices.Delete(root.DocList, i, i+1)
 			closed = append(closed, doc.FileName+doc.Caption)
 			if docNum == i {
 				docNum--
@@ -192,6 +207,9 @@ func (root *Root) logDisplay(ctx context.Context) {
 func (root *Root) toNormal(ctx context.Context) {
 	root.mu.RLock()
 	defer root.mu.RUnlock()
+	if root.CurrentDoc < 0 || root.CurrentDoc >= len(root.DocList) {
+		return
+	}
 	m := root.DocList[root.CurrentDoc]
 	root.setDocument(ctx, m)
 }
