@@ -67,6 +67,11 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 	case *eventSearchMove:
 		root.searchGo(ctx, ev.ln, ev.searcher)
 	case *eventReachEOF:
+		// Quit if small doc and config allows
+		if root.quitCheck() {
+			return true
+		}
+		root.Config.QuitSmall = false
 		root.notifyEOFReached(ev.m)
 
 	// Input confirmation action event.
@@ -386,19 +391,17 @@ func (root *Root) sendReachEOF(m *Document) {
 
 // monitorEOF monitors the EOF of the document.
 func (root *Root) monitorEOF() {
-	if root.Config.NotifyEOF == 0 {
-		return
-	}
-	log.Println("monitorEOF")
 	for _, m := range root.DocList {
-		go func() {
-			if !m.BufEOF() {
-				m.cond.L.Lock()
-				m.cond.Wait()
-				m.cond.L.Unlock()
-			}
-			root.sendReachEOF(m)
-			log.Println("EOF reached", m.FileName)
-		}()
+		go root.waitForEOF(m)
 	}
 }
+
+// waitForEOF waits for a document to reach EOF and sends notification.
+func (root *Root) waitForEOF(m *Document) {
+	if !m.BufEOF() {
+		m.cond.L.Lock()
+		m.cond.Wait()
+		m.cond.L.Unlock()
+	}
+	root.sendReachEOF(m)
+}
