@@ -115,27 +115,6 @@ func (substr regexpWord) String() string {
 	return substr.word
 }
 
-// stripRegexpES is a regular expression that excludes escape sequences.
-var stripRegexpES = regexp.MustCompile("(\x1b\\[[\\d;*]*m)|.\b")
-
-// stripEscapeSequenceString strips if it contains escape sequences.
-func stripEscapeSequenceString(src string) string {
-	if !strings.ContainsAny(src, "\x1b\b") {
-		return src
-	}
-	// Remove EscapeSequence.
-	return stripRegexpES.ReplaceAllString(src, "")
-}
-
-// stripEscapeSequence strips if it contains escape sequences.
-func stripEscapeSequenceBytes(src []byte) []byte {
-	if !bytes.ContainsAny(src, "\x1b\b") {
-		return src
-	}
-	// Remove EscapeSequence.
-	return stripRegexpES.ReplaceAll(src, []byte(""))
-}
-
 // NewSearcher returns the Searcher interface suitable for the search term.
 func NewSearcher(word string, searchReg *regexp.Regexp, caseSensitive bool, regexpSearch bool) Searcher {
 	if regexpSearch && word != regexp.QuoteMeta(word) {
@@ -174,6 +153,8 @@ func regexpCompile(r string, caseSensitive bool) *regexp.Regexp {
 	r = regexp.QuoteMeta(r)
 	re, err = regexp.Compile(r)
 	if err != nil {
+		// This should never happen since QuoteMeta escapes all special characters
+		// making the string a valid regular expression, but we handle it for safety.
 		log.Printf("regexpCompile failed %s:%v\n", r, err)
 		return nil
 	}
@@ -476,18 +457,27 @@ func (root *Root) cancelWait(cancel context.CancelFunc) error {
 	if err != nil {
 		return err
 	}
-	// Allow only some events while searching.
+	// eventQueue stores events that occur during search.
+	var eventQueue []tcell.Event
 	for {
 		ev := root.Screen.PollEvent()
 		switch ev := ev.(type) {
 		case *tcell.EventKey: // cancel key?
 			c.Capture(ev)
-		case *eventSearchQuit: // found
+		case *eventSearchQuit, *eventSearchMove: // found or moved
+			// Replay events that occurred during the search.
+			for _, queued := range eventQueue {
+				root.postEvent(queued)
+			}
 			return nil
 		case *eventUpdateEndNum:
 			root.updateEndNum()
+		case *eventReachEOF:
+			eventQueue = append(eventQueue, ev)
 		default:
 			// ignore other events.
+			log.Println("cancelWait: ignore event", ev)
+			return nil
 		}
 	}
 }
